# Fortanix SDKMS Java Client Development Kit

This development kit includes the Java client library, documentation
on the library itself, and sample programs demonstrating how to
connect to an SDKMS server instance and perform cryptograhic
operations.

## Introduction to SDKMS

Please see https://support.fortanix.com/sdkms for an introduction to
SDKMS and its APIs.

## API Documentation

The Java API documentation can be found in `apidocs`.

## How to Build the Sample Applications

The sample applications are built using maven. They have been built and
tested with openJDK-8 on Ubuntu.

```
cd examples
mvn package
```

## Prerequisites for Running the Samples

1. An SDKMS server instance to run the sample application against. You may use
the cloud based instance at https://apps.smartkey.io (if you have an
account there), or you may use an on-premise SDKMS server.
2. An application in your SDKMS instance. The majority of the examples use
API key authentication, so your application must be configured to use API
key auth.
3. If you are using an on-premise SDKMS server, you may need to configure
a Java trust store containing the server's TLS certificate or appropriate
trust anchors.
4.  The ClientCertificate example requires an application configured
to use Client Certificate based authentication. For this test, you will
also need a PKCS#12 archive containing the client certificate provisioned
for the applictaion and the private key corresponding to that certificate.

## How to Run the Sample Applications

After building the sample applications, they can be run with the scripts in
the bin directory. For example:

```
bin/BatchCrypto
```

All of the samples may be run with the --help option to print a usage string.

The AesCbcCrypto, AesGcmCrypto, and PubKeyCrypto examples all take input
on stdin and output on stdout. If they appear to hang, they are probably
waiting for input on stdin.

## List of Included Examples

* AesCbcCrypto demonstrates how to encrypt and decrypt data using AES CBC
  mode.
* AesGcmCrypto demonstrates how to encrypt and decrypt data using AES with 
  authenticating cryptographic modes like AES-GCM and AES-CCM.
* BatchCrypto demonstrates using the batch encrypt and batch decrypt APIs.
* ClientCertificate.java demonstrates how to authenticate an application to
  SDKMS using a client certificate.
* PubKeyCrypto demonstrates how to perform public key cryptography using
  an RSA key.
